@@ -5,6 +5,7 @@
 #include <QtLocation/QGeoCoordinate>
 #include <QtLocation/QGeoMapObject>
 #include <QPushButton>
+#include <QtLocation/QGraphicsGeoMap>
 
 class TrailInterface;
 class QGraphicsView;
@@ -23,8 +24,10 @@ signals:
 
 public slots:
     void addMapObject(QtMobility::QGeoMapObject*);
+    void removeMapObject(QtMobility::QGeoMapObject*);
     void clearMapObjects();
     void setCenter(QtMobility::QGeoCoordinate);
+    void setConnectivityMode(QtMobility::QGraphicsGeoMap::ConnectivityMode);
 
 private slots:
     void zoomIn();
